@@ -9,7 +9,7 @@ use Carp;
 use Config;
 use Math::DCT 'dct2d';
 
-our $VERSION = '0.0_1';
+our $VERSION = '0.0_2';
 
 =head1 NAME
 
@@ -60,7 +60,9 @@ bitmap methods.
 A fast DCT module made for the specific purpose is used (L<Math::DCT> - over 10x
 faster than the pHash.org C++ implementation).
 
-=head1 CONSTRUCTOR METHODS
+=head1 CONSTRUCTOR METHOD
+
+=head2 C<new>
 
   my $iph = Image::PHash->new($image_file , $library?, \%settings?);
   
@@ -279,7 +281,7 @@ Will convert a bit value string to a hex string.
 
 Will calculate the bit difference of two hex string hashes (their Hamming distance
 of their bit stream form). On 64 bit systems (checking C<$Config{ivsize}>) it will
-actually call C<diff64> which can calculate the difference of up to 64bit hashes in
+actually call C<_diff64> which can calculate the difference of up to 64bit hashes in
 a single operation (using C<%064b>).
 
 =head1 NOTES
@@ -395,10 +397,10 @@ sub new {
     croak("resize > 5 expected.") unless $self->{dct_size} > 5;
 
     my %libs = ( # Library, reduce/resize function, pixels function, support for passing data variable
-        Imlib2      => ['Image::Imlib2', \&reduce_Imlib2, \&pixels_Imlib2],
-        GD          => ['GD', \&reduce_GD, \&pixels_GD, 1],
-        ImageMagick => ['Image::Magick', \&reduce_Magick, \&pixels_Magick, 1],
-        Imager      => ['Imager', \&reduce_Imager, \&pixels_Imager, 1],
+        Imlib2      => ['Image::Imlib2', \&_reduce_Imlib2, \&_pixels_Imlib2],
+        GD          => ['GD', \&_reduce_GD, \&_pixels_GD, 1],
+        ImageMagick => ['Image::Magick', \&_reduce_Magick, \&_pixels_Magick, 1],
+        Imager      => ['Imager', \&_reduce_Imager, \&_pixels_Imager, 1],
     );
 
     my $file = -f $self->{image};
@@ -458,11 +460,11 @@ sub new {
     $self->{pixels}  = $libs{$self->{module}}->[2];
 
     $self->{methods} = {
-        average   => \&apply_average,
-        average_x => \&apply_average,
-        median    => \&apply_median,
-        diff      => \&apply_diff,
-        log       => \&apply_log_average,
+        average   => \&_apply_average,
+        average_x => \&_apply_average,
+        median    => \&_apply_median,
+        diff      => \&_apply_diff,
+        log       => \&_apply_log_average,
     };
 
     return $self;
@@ -493,7 +495,7 @@ sub b2h {
 # Difference in bits between two hex strings
 # About 30% slower than using %064b directly, but this is portable to 32 bits
 sub diff {
-    return diff64(@_) if length($_[0]) <= 16 && $Config{ivsize} >= 8;
+    return _diff64(@_) if length($_[0]) <= 16 && $Config{ivsize} >= 8;
     my $diff;
     for (my $i = 0; $i < length($_[0]); $i += 8) {
         my $d =
@@ -504,7 +506,7 @@ sub diff {
     return $diff;
 }
 
-sub diff64 {
+sub _diff64 {
     my $k = sprintf("%064b", hex($_[0]));
     my $l = sprintf("%064b", hex($_[1]));
     my $diff = $k ^ $l;
@@ -513,7 +515,7 @@ sub diff64 {
 }
 
 # Reduce the size of an image using Imlib2
-sub reduce_Imlib2 {
+sub _reduce_Imlib2 {
     my $self = shift;
     return $self->{im_scaled} = $self->{im}
         if $self->{im}->width == $self->{dct_size}
@@ -524,7 +526,7 @@ sub reduce_Imlib2 {
 }
 
 # Reduce the size of an image using GD
-sub reduce_GD {
+sub _reduce_GD {
     my $self = shift;
     $self->{im_scaled} = $self->{im};
     return
@@ -542,7 +544,7 @@ sub reduce_GD {
 }
 
 # Reduce the size of an image using Image::Magick
-sub reduce_Magick {
+sub _reduce_Magick {
     my $self = shift;
     $self->{im_scaled} = $self->{im};
     
@@ -558,7 +560,7 @@ sub reduce_Magick {
 }
 
 # Reduce the size of an image using Imager
-sub reduce_Imager {
+sub _reduce_Imager {
     my $self = shift;
     return $self->{im_scaled} = $self->{im}
         if $self->{im}->getwidth() == $self->{dct_size}
@@ -573,7 +575,7 @@ sub reduce_Imager {
 }
 
 # Return the pixel values for an image when using Imlib2
-sub pixels_Imlib2 {
+sub _pixels_Imlib2 {
     my $self = shift;
     my @pixels;
     for (my $y = 0; $y < $self->{dct_size}; $y++) {
@@ -589,7 +591,7 @@ sub pixels_Imlib2 {
 }
 
 # Return the pixel values for an image when using GD
-sub pixels_GD {
+sub _pixels_GD {
     my $self = shift;
     my @pixels;
     for (my $y = 0; $y < $self->{dct_size}; $y++) {
@@ -606,7 +608,7 @@ sub pixels_GD {
 }
 
 # Return the pixel values for an image when using Image::Magick
-sub pixels_Magick {
+sub _pixels_Magick {
     my $self = shift;
     my @pixels;
     for (my $y = 0; $y < $self->{dct_size}; $y++) {
@@ -629,7 +631,7 @@ sub pixels_Magick {
 }
 
 # Return the pixel values for an image when using Imager
-sub pixels_Imager {
+sub _pixels_Imager {
     my $self = shift;
     my @pixels;
     for (my $y = 0; $y < $self->{dct_size}; $y++) {
@@ -658,7 +660,7 @@ sub dctdump {
 
     $self->{reduced}->($self, %opt) unless $self->{im_scaled};
     $self->{dct} ||= dct2d($self->{pixels}->(($self, %opt)));
-    my $dctv = $self->mirroring(%opt);
+    my $dctv = $self->_mirroring(%opt);
 
     return $self->{$dctv};
 }
@@ -693,22 +695,22 @@ sub printbitmatrix {
     return $str;
 }
 
-sub mirroring {
+sub _mirroring {
     my ($self, %opt) = @_;
 
     my $dctv = 'dct';
     if ($opt{mirrorproof}) {
         $dctv = 'mirrorproof';
-        $self->{$dctv} ||= dct_mirrorproof($self->{dct});
+        $self->{$dctv} ||= _dct_mirrorproof($self->{dct});
         croak("Options 'mirror' and 'mirrorproof' are mutually exclusive") if $opt{mirror};
     } elsif ($opt{mirror}) {
         $dctv = 'mirror';
-        $self->{$dctv} ||= dct_mirror($self->{dct});
+        $self->{$dctv} ||= _dct_mirror($self->{dct});
     }
     return $dctv;    
 }
 
-sub validate_options {
+sub _validate_options {
     my ($self, %opt) = @_;
     my %valid = (
         geometry    => 1,
@@ -730,7 +732,7 @@ sub validate_options {
     } else {
         croak("geometry expected to be either 'NxN' for square matrix, or number of bits");
     }
-    croak("Unsupported method. Choose from: ".keys($self->{methods}->%*))
+    croak("Unsupported method. Choose from: ".keys(%{$self->{methods}}))
         unless $self->{methods}->{$opt{method}};
 
     return %opt;
@@ -738,12 +740,12 @@ sub validate_options {
 
 sub pHash {
     my $self = shift;
-    my %opt  = $self->validate_options(@_);
+    my %opt  = $self->_validate_options(@_);
 
     $self->{reduced}->($self, %opt) unless $self->{im_scaled};
     $self->{dct} ||= dct2d($self->{pixels}->($self, %opt));
 
-    my $dctv = $self->mirroring(%opt);
+    my $dctv = $self->_mirroring(%opt);
 
     my (@array, @extra);
     my $x_mult = ($opt{method} eq 'median' || $opt{method} eq 'average_x') ? 1 : 0;
@@ -790,67 +792,67 @@ sub pHash {
     }
 }
 
-sub dct_mirror {
-    my $dct = shift;
-    my $t = 1;
-    my @mirror = map { ($t^=1) ? -$_ : $_ } @$dct;
+sub _dct_mirror {
+    my $dct    = shift;
+    my $t      = 1;
+    my @mirror = map {($t ^= 1) ? -$_ : $_} @$dct;
     return \@mirror;
 }
 
-sub dct_mirrorproof {
-    my $dct = shift;
-    my $t = 1;
-    my @mirror = map { ($t^=1) ? abs($_) : $_ } @$dct;
+sub _dct_mirrorproof {
+    my $dct    = shift;
+    my $t      = 1;
+    my @mirror = map {($t ^= 1) ? abs($_) : $_} @$dct;
     return \@mirror;
 }
 
-sub apply_average {
-    my $array = shift;
-    my $skip  = shift || 0;
-    my $extra = shift || [];
+sub _apply_average {
+    my $array   = shift;
+    my $skip    = shift || 0;
+    my $extra   = shift || [];
     my $average = 0;
-    $average += $array->[$_] foreach $skip..$#$array;
-    $average += $_ foreach @$extra;
+    $average += $array->[$_] foreach $skip .. $#$array;
+    $average += $_           foreach @$extra;
     $average /= scalar(@$array) + scalar(@$extra) - $skip;
-    $array->[$_] = $array->[$_] >= $average ? '1' : '0' foreach 0..$#$array;
+    $array->[$_] = $array->[$_] >= $average ? '1' : '0' foreach 0 .. $#$array;
 }
 
-sub apply_log_average {
+sub _apply_log_average {
     my $array   = shift;
     my $skip    = shift || 0;
     my $exp     = 1 + (scalar(@$array)**(1 / 6));
     my $average = 0;
-    foreach ($skip..$#$array) {
-        my $add = abs($array->[$_]) ** (1/$exp);
+    foreach ($skip .. $#$array) {
+        my $add = abs($array->[$_])**(1 / $exp);
         $average += $array->[$_] < 0 ? -$add : $add;
     }
     $average /= scalar(@$array) - $skip;
-    my $thres = $average ** $exp;
+    my $thres = $average**$exp;
     $thres *= -1 if $average < 0;
-    $array->[$_] = $array->[$_] >= $thres ? '1' : '0' foreach 0..$#$array;
+    $array->[$_] = $array->[$_] >= $thres ? '1' : '0' foreach 0 .. $#$array;
 }
 
-sub apply_diff {
-    my $array   = shift;
-    my $prev = 0;
-    foreach (0..$#$array) {
+sub _apply_diff {
+    my $array = shift;
+    my $prev  = 0;
+    foreach (0 .. $#$array) {
         my $diff = $array->[$_] > $prev ? 1 : 0;
         $prev = $array->[$_];
         $array->[$_] = $diff;
     }
 }
 
-sub apply_median {
-    my $array  = shift;
-    my $skip   = shift || 0;
-    my $extra  = shift || [];
-    my @vals   = sort {$a <=> $b} @$array, @$extra;
-    my $len    = scalar @vals - $skip;
+sub _apply_median {
+    my $array = shift;
+    my $skip  = shift || 0;
+    my $extra = shift || [];
+    my @vals  = sort {$a <=> $b} @$array, @$extra;
+    my $len   = scalar @vals - $skip;
     my $thresh =
           $len % 2
         ? $vals[int($len / 2)]
         : ($vals[int($len / 2) - 1] + $vals[int($len / 2)]) / 2;
-    $array->[$_] = $array->[$_] >= $thresh ? '1' : '0' foreach 0..$#$array;
+    $array->[$_] = $array->[$_] >= $thresh ? '1' : '0' foreach 0 .. $#$array;
 }
 
 =head1 ACKNOWLEDGEMENTS
